@@ -11,6 +11,21 @@
  *
  * ----------------------------------------------------------------------- */
 
+/* ----------------------------------------------------------------------- *
+ *
+ *   02.06.2009 Calculate Pack http://www.calculate-linux.org
+ *   В исходный код main.c вненсены следующие изменения:
+ *   - вывод TABMSG происходит без учета HSHIFT
+ *   - клавиши F1 отображают текстовое сообщение только если файл .txt
+ *   или .msg
+ *   - по клавиши ESC в меню проиходит возврат в главное меню
+ *   - модуль аккумулирует неиспользуемые параметры, которые впоследствии
+ *   передает дальше
+ *   - для указания пункта по умолчанию используется параметры командной
+ *   строки
+ *
+ * ----------------------------------------------------------------------- */
+
 /*
  * menumain.c
  *
@@ -68,6 +83,8 @@ const struct menu_parameter mparm[NPARAMS] = {
 #define VSHIFT		(cm->mparm[P_VSHIFT])
 #define HIDDEN_ROW	(cm->mparm[P_HIDDEN_ROW])
 
+/* transfering buffer by default */
+char default_tail_cmdline[MAX_CMDLINE_LEN];
 /* transfering buffer */
 char tail_cmdline[MAX_CMDLINE_LEN];
 /* number of parameter in defaultparam */ 
